###########
 Inference
###########

This module provides the underlying inference functionality for the
`earthkit-workflows-anemoi` package, and is at times a thin wrapper
around the `anemoi-inference` package.

For simple tasks, the fluent API is recommended, which provides a more
user-friendly interface to create and manage workflows.

.. _inference:

.. automodule:: earthkit.workflows.plugins.anemoi.inference
   :members:
   :no-undoc-members:
   :show-inheritance:
